@@ -33,9 +33,10 @@
 #  define OKTETAKASTENGUI_DEPRECATED_NO_EXPORT OKTETAKASTENGUI_NO_EXPORT OKTETAKASTENGUI_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define OKTETAKASTENGUI_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef OKTETAKASTENGUI_NO_DEPRECATED
+#    define OKTETAKASTENGUI_NO_DEPRECATED
+#  endif
 #endif
 
 #endif
