@@ -33,9 +33,10 @@
 #  define OKTETACORE_DEPRECATED_NO_EXPORT OKTETACORE_NO_EXPORT OKTETACORE_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define OKTETACORE_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef OKTETACORE_NO_DEPRECATED
+#    define OKTETACORE_NO_DEPRECATED
+#  endif
 #endif
 
 #endif
