@@ -33,9 +33,10 @@
 #  define OKTETAGUI_DEPRECATED_NO_EXPORT OKTETAGUI_NO_EXPORT OKTETAGUI_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define OKTETAGUI_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef OKTETAGUI_NO_DEPRECATED
+#    define OKTETAGUI_NO_DEPRECATED
+#  endif
 #endif
 
 #endif
